"use strict";
/**
 * Serverless - Reload
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Reload = void 0;
const config_1 = require("../../config/config");
const getAllContentfulData_1 = require("../../utils/getAllContentfulData/getAllContentfulData");
const utils_1 = require("../../utils/utils");
const Render_1 = require("../../render/Render");
/**
 * Function - output paginated and/or filtered page on browser reload
 *
 * @param {import('./ReloadTypes').ReloadArgs} args
 * @return {Promise<Response>} Response
 */
const Reload = async ({ request, env, next, siteConfig }) => {
    try {
        /* Query */
        const { searchParams, pathname } = new URL(request.url);
        const page = searchParams.get('page');
        const filters = searchParams.get('filters');
        const path = pathname;
        const query = {};
        let noPage = false;
        let noFilters = false;
        if ((0, utils_1.isStringStrict)(page)) {
            query.page = page;
        }
        else {
            noPage = true;
        }
        if ((0, utils_1.isStringStrict)(filters)) {
            query.filters = filters;
        }
        else {
            noFilters = true;
        }
        /* No query move on to default page */
        if (noPage || noFilters) {
            return next();
        }
        /* Config */
        (0, config_1.setConfig)(siteConfig);
        (0, utils_1.setFilters)(siteConfig.filters);
        (0, utils_1.setActions)(siteConfig.actions);
        (0, utils_1.setShortcodes)(siteConfig.shortcodes);
        if ((0, utils_1.isObjectStrict)(env)) {
            config_1.config.env.dev = env.ENVIRONMENT === 'dev';
            config_1.config.env.prod = env.ENVIRONMENT === 'production';
        }
        /* Data params */
        const serverlessData = { query, path };
        /* Output */
        const data = await (0, Render_1.Render)({
            serverlessData,
            allData: await (0, getAllContentfulData_1.getAllContentfulData)({
                serverlessData
            })
        });
        let html = '';
        if ((0, utils_1.isObjectStrict)(data)) {
            html = data.output !== undefined ? data.output : '';
        }
        return new Response(html, {
            status: 200,
            headers: {
                'Content-Type': 'text/html;charset=UTF-8'
            }
        });
    }
    catch (error) {
        console.error(config_1.config.console.red, '[SSF] Error with reload function: ', error);
        let statusCode = 500;
        if ((0, utils_1.isObjectStrict)(error)) {
            const err = error;
            if ((0, utils_1.isNumber)(err.httpStatusCode)) {
                statusCode = err.httpStatusCode;
            }
        }
        let html = '';
        if ((0, utils_1.isFunction)(config_1.config.renderFunctions.httpError)) {
            html = await config_1.config.renderFunctions.httpError(statusCode);
        }
        return new Response(html, {
            status: statusCode,
            headers: {
                'Content-Type': 'text/html;charset=UTF-8'
            }
        });
    }
};
exports.Reload = Reload;
