"use strict";
/**
 * Utils - Get Archive Link
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getArchiveLink = void 0;
const config_1 = require("../../config/config");
const isString_1 = require("../isString/isString");
const getArchiveId_1 = require("../getArchiveId/getArchiveId");
const getPermalink_1 = require("../getPermalink/getPermalink");
const getSlug_1 = require("../getSlug/getSlug");
/**
 * Function - get archive link by content type
 *
 * @param {string} contentType
 * @param {string} [linkContentType]
 * @return {import('./getArchiveLinkTypes').ArchiveLinkReturn}
 */
const getArchiveLink = (contentType = '', linkContentType) => {
    let archiveLink = '';
    let archiveTitle = '';
    const archiveId = (0, getArchiveId_1.getArchiveId)(contentType, linkContentType);
    const archiveInfo = config_1.config.slug.archives[archiveId];
    archiveTitle = config_1.config.contentTypes.archive[contentType].plural;
    if (archiveInfo !== undefined) {
        const archiveSlug = archiveInfo.slug;
        if ((0, isString_1.isStringStrict)(archiveId) && (0, isString_1.isStringStrict)(archiveSlug)) {
            const s = (0, getSlug_1.getSlug)({
                id: archiveId,
                slug: archiveSlug,
                contentType: 'page'
            });
            if ((0, isString_1.isStringStrict)(s)) {
                archiveLink = (0, getPermalink_1.getPermalink)(s);
            }
        }
    }
    return {
        title: archiveTitle,
        link: archiveLink
    };
};
exports.getArchiveLink = getArchiveLink;
